@@ -12,8 +12,9 @@ const u = require('unist-builder');
 const fs = require('mz/fs');
 const fecha = require('fecha');
 require('any-observable/register/rxjs-all');
-const Observable = require('any-observable');
-const streamToObservable = require('stream-to-observable');
+const {merge} = require('rxjs');
+const {filter} = require('rxjs/operators');
+const streamToObservable = require('@samverschueren/stream-to-observable');
 const pkg = require('./package.json');
 
 const log = bunyan.createLogger({
@@ -35,10 +36,11 @@ const repo = git(__dirname);
 const exec = (cmd, args) => {
     const cp = execa(cmd, args);
 
-    return Observable.merge(
-        streamToObservable(cp.stdout.pipe(split()), { await: cp }),
-        streamToObservable(cp.stderr.pipe(split()), { await: cp })
-    ).filter(Boolean);
+    return merge(
+        streamToObservable(cp.stdout.pipe(split())),
+        streamToObservable(cp.stderr.pipe(split())),
+        cp,
+    ).pipe(filter(Boolean));
 };
 
 const enabled = ctx => ctx.version !== currentVersion;
@@ -114,7 +116,7 @@ const tasks = new Listr([
     },
     {
         title: 'Packing caniuse data',
-        task: () => exec('babel-node', ['src/packer/index.js']),
+        task: () => exec('npx', ['babel-node', 'src/packer/index.js']),
         enabled,
     },
     {
